==> snips-sam-0.0.24.tgz: package/src/commands/test/mqtt.ts <==
import * as yargs from 'yargs'
import { cli } from '../../cli'
import { SSHService } from '../../session/ssh'
import { timeout } from '../../utils'

exports.command = 'mqtt [toggle]'
exports.desc = false

exports.handler = async (argv: yargs.Argv) => {
    cli.stream.loading('Sending MQTT messages')
    const toggle = JSON.parse(JSON.stringify(argv)).toggle

    const ssh = new SSHService()
    await ssh.connect()
    .catch(e => {
        cli.stream.error(e)
        process.exit()
    })

    // await ssh.run('sudo apt-get install -y mosquitto-clients')
    // .catch(_ => {})
    await ssh.run(`mosquitto_pub -t hermes/dialogueManager/sessionStarted -m '{"sessionId":"da4aec4c-b37a-4440-a3fa-d82d0d307932","customData":null,"siteId":"default","reactivatedFromSessionId":null}' `)
    .then(async _ => await timeout(500))
    // .then(_ => ssh.run(`mosquitto_pub -t hermes/nlu/query -m '{"input":"turn ${toggle} the lights in the kitchen","intentFilter":null,"id":"ef2b0dbb-db1f-47f3-b3c1-33d733413414","sessionId":"da4aec4c-b37a-4440-a3fa-d82d0d307932"}' `))
    .then(_ => ssh.run(`mosquitto_pub -t hermes/nlu/lightsTurnOnSet -m '{"sessionId":"da4aec4c-b37a-4440-a3fa-d82d0d307932","customData":null,"siteId":"default","input":"turn on the lights in the kitchen","intent":{"intentName":"lightsTurnOnSet","probability":0.8168273},"slots":[{"rawValue":"kitchen","value":{"kind":"Custom","value":"kitchen"},"range":{"start":26,"end":33},"entity":"house_room","slotName":"house_room"}]}' `))

    .then(async _ => await timeout(1000))
    .then(_ => ssh.run(`mosquitto_pub -t hermes/dialogueManager/sessionEnded -m '{"sessionId":"da4aec4c-b37a-4440-a3fa-d82d0d307932","customData":null,"termination":{"reason":"timeout"},"siteId":"default"}' `))
    cli.stream.success()
    ssh.disconnect()
    process.exit(0)
}

==> snips-sam-0.0.27.tgz: package/src/commands/test/mqtt.ts <==
import * as yargs from 'yargs'
import { cli } from '../../cli'
import { SSHService } from '../../session/ssh'
import { timeout } from '../../utils'

exports.command = 'mqtt [toggle]'
exports.desc = false

exports.handler = async (argv: yargs.Argv) => {
    cli.stream.loading('Sending MQTT messages')
    // const toggle = JSON.parse(JSON.stringify(argv)).toggle

    const ssh = new SSHService()
    await ssh.connect()
    .catch(e => {
        cli.stream.error(e)
        process.exit()
    })

    // await ssh.run('sudo apt-get install -y mosquitto-clients')
    // .catch(_ => {})
    await ssh.run(`mosquitto_pub -t hermes/dialogueManager/sessionStarted -m '{"sessionId":"da4aec4c-b37a-4440-a3fa-d82d0d307932","customData":null,"siteId":"default","reactivatedFromSessionId":null}' `)
    .then(async _ => await timeout(500))
    // .then(_ => ssh.run(`mosquitto_pub -t hermes/nlu/query -m '{"input":"turn ${toggle} the lights in the kitchen","intentFilter":null,"id":"ef2b0dbb-db1f-47f3-b3c1-33d733413414","sessionId":"da4aec4c-b37a-4440-a3fa-d82d0d307932"}' `))
    .then(_ => ssh.run(`mosquitto_pub -t hermes/nlu/lightsTurnOnSet -m '{"sessionId":"da4aec4c-b37a-4440-a3fa-d82d0d307932","customData":null,"siteId":"default","input":"turn on the lights in the kitchen","intent":{"intentName":"lightsTurnOnSet","probability":0.8168273},"slots":[{"rawValue":"kitchen","value":{"kind":"Custom","value":"kitchen"},"range":{"start":26,"end":33},"entity":"house_room","slotName":"house_room"}]}' `))

    .then(async _ => await timeout(1000))
    .then(_ => ssh.run(`mosquitto_pub -t hermes/dialogueManager/sessionEnded -m '{"sessionId":"da4aec4c-b37a-4440-a3fa-d82d0d307932","customData":null,"termination":{"reason":"timeout"},"siteId":"default"}' `))
    cli.stream.success()
    ssh.disconnect()
    process.exit(0)
}
